from django.forms import (
    CharField,
)

from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)
from utilities.forms import (
    DynamicModelChoiceField,
)

from netbox_storage.models import Filesystem, WindowsVolume


class WindowsVolumeForm(NetBoxModelForm):
    """Form for creating a new LinuxVolume object."""

    drive_name = CharField(
        label="Drive Name",
    )
    fs = DynamicModelChoiceField(
        queryset=Filesystem.objects.all(),
        label="Filesystem Name",
    )
    drives = DynamicModelChoiceField(
        queryset=Filesystem.objects.all(),
        label="Drives",
    )

    class Meta:
        model = WindowsVolume

        fields = (
            "drive_name",
            "fs",
            "drives",
            "description",
        )


class WindowsVolumeFilterForm(NetBoxModelFilterSetForm):
    """Form for filtering LinuxVolume instances."""

    model = WindowsVolume

    drive_name = CharField(
        required=False,
        label="VG Name",
    )
    fs = DynamicModelChoiceField(
        queryset=Filesystem.objects.all(),
        required=False,
        label="Filesystem Name",
    )


class WindowsVolumeImportForm(NetBoxModelImportForm):
    fs = DynamicModelChoiceField(
        queryset=Filesystem.objects.all(),
        required=False
    )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    class Meta:
        model = WindowsVolume

        fields = (
            "drive_name",
            "fs",
            "description",
        )


class WindowsVolumeBulkEditForm(NetBoxModelBulkEditForm):
    model = WindowsVolume

    drive_name = CharField(
        required=False,
        label="Drive Name",
    )
    fs = DynamicModelChoiceField(
        queryset=Filesystem.objects.all(),
        required=False
    )
    description = CharField(max_length=255, required=False)

    fieldsets = (
        (
            None,
            ("drive_name", "fs", "description"),
        ),
    )
    nullable_fields = ["description"]




from extras.plugins import PluginTemplateExtension

from netbox_storage.models import Drive
from netbox_storage.tables import RelatedDriveTable
from dcim.models import Platform


class RelatedDrives(PluginTemplateExtension):
    model = "virtualization.virtualmachine"

    def full_width_page(self):
        obj = self.context.get("object")

        drives = Drive.objects.filter(
            virtual_machine=obj
        )
        drive_table = RelatedDriveTable(
            data=drives
        )

        platform = obj.platform
        if platform.name.__contains__('Windows'):
            return self.render(
                "netbox_storage/volume/windowsvolume_box.html",
                extra_context={
                    "drives": drives,
                },
            )
        else:
            return self.render(
                "netbox_storage/volume/linuxvolume_box.html",
                extra_context={
                    "related_drives": drive_table,
                },
            )


template_extensions = [RelatedDrives]
